CreateTemplate class

Constructors

CreateTemplate({String? moduleName, String? destinationDir})

Properties

defaultName → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
moduleName → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
setDestinationDirectory ← String
no getter
setModuleName ← String
no getter
setTemplateDirectory ← String
no getter
templateDirectory → Directory
no setter

Methods

copyDirectory({required Directory source, required Directory destination, bool? isMainDest}) → Future<void>
getDefaultModuleName() → Future<void>
getDestinationDirectory() → dynamic
getModuleName() → dynamic
getTemplateDirectory() → dynamic
individualFileOperations({required File file, required String newPath}) → Future
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
operation() → Future
printDirectoryContents(Directory directory, {int level = 0}) → dynamic
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited