Config class

Constructors

Config({String? templatePath, String? defaultModuleName})
Config.fromJson(String source)
factory
Config.fromMap(Map<String, dynamic> map)
factory

Properties

defaultModuleName ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
templatePath ↔ String?
getter/setter pair

Methods

copyWith({String? templatePath, String? defaultModuleName}) → Config
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant Config other) → bool
The equality operator.
override

Static Methods

fromFile() → Future<Config>
reset() → Future<void>
save({String? defaultName, String? templatePath}) → Future<void>